/*
 * Copyright (c) 2010, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package org.glassfish.jersey.tests.e2e.json.entity;

import jakarta.xml.bind.annotation.XmlRootElement;

/**
 * @author Jakub Podlesak
 */
@SuppressWarnings("RedundantIfStatement")
@XmlRootElement
public class EmptyElementBean {

    public String nullOnly = null;

    public static Object createTestInstance() {
        EmptyElementBean result = new EmptyElementBean();
        result.nullOnly = null;

        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final EmptyElementBean other = (EmptyElementBean) obj;
        if ((this.nullOnly == null) ? (other.nullOnly != null) : !this.nullOnly.equals(other.nullOnly)) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 3;
        hash = 13 * hash + (this.nullOnly != null ? this.nullOnly.hashCode() : 0);
        return hash;
    }

    @Override
    public String toString() {
        return String.format("{nullOnly:%s}", nullOnly);
    }

}
